"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiKeyService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const crypto_1 = require("crypto");
const repositories_1 = require("../repositories");
let ApiKeyService = class ApiKeyService {
    constructor(clientApp) {
        this.clientApp = clientApp;
    }
    async verify(apiKey, apiSecret) {
        try {
            const apiKeysObject = await this.clientApp.findOne({
                where: {
                    apiKey,
                    apiSecret,
                },
            });
            return !!apiKeysObject;
        }
        catch (error) {
            throw new rest_1.HttpErrors.InternalServerError('Error verifying API keys');
        }
    }
    async generateSignature(event, timestamp) {
        const apiKeyData = await this.clientApp.findOne({
            where: {
                apiKey: event.apiKey,
            },
        });
        if (!apiKeyData) {
            throw new rest_1.HttpErrors.Unauthorized('Invalid API key');
        }
        const hmac = (0, crypto_1.createHmac)('sha256', apiKeyData.apiSecret);
        hmac.update(`${JSON.stringify(event)}:${timestamp}`);
        return hmac.digest('hex');
    }
};
exports.ApiKeyService = ApiKeyService;
exports.ApiKeyService = ApiKeyService = tslib_1.__decorate([
    (0, core_1.injectable)(),
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.ClientAppRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.ClientAppRepository])
], ApiKeyService);
//# sourceMappingURL=api-key.service.js.map