"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskHttpComponent = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const sequelize_1 = require("@sourceloop/core/sequelize");
const keys_1 = require("../../keys");
const controllers_1 = require("./controllers");
const http_stream_service_1 = require("./http-stream.service");
const repositories_1 = require("./repositories");
const sequelize_2 = require("./repositories/sequelize");
const services_1 = require("./services");
let TaskHttpComponent = class TaskHttpComponent {
    constructor(app, config) {
        this.app = app;
        this.config = config;
        this.controllers = [
            controllers_1.ClientAppController,
            controllers_1.WebhookSubscriptionController,
            controllers_1.EventTriggerController,
        ];
        if (config === null || config === void 0 ? void 0 : config.useSequelize) {
            this.repositories = [
                sequelize_2.ClientAppRepository,
                sequelize_2.WebhookSubscriptionRepository,
                sequelize_1.JwtKeysRepository,
            ];
        }
        else {
            this.repositories = [
                repositories_1.ClientAppRepository,
                repositories_1.WebhookSubscriptionRepository,
                core_2.JwtKeysRepository,
            ];
        }
        this.services = [services_1.ApiKeyService, services_1.WebhookService];
        this.app
            .bind(keys_1.TaskServiceBindings.INCOMING_CONNECTOR)
            .toClass(http_stream_service_1.HttpStreamService)
            .inScope(core_1.BindingScope.SINGLETON);
        this.app
            .bind(keys_1.TaskServiceBindings.OUTGOING_CONNECTOR)
            .toClass(http_stream_service_1.HttpStreamService)
            .inScope(core_1.BindingScope.SINGLETON);
    }
};
exports.TaskHttpComponent = TaskHttpComponent;
exports.TaskHttpComponent = TaskHttpComponent = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.TaskServiceBindings.CONFIG, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], TaskHttpComponent);
//# sourceMappingURL=task-http.component.js.map